@@ -1,5 +1,5 @@
-from __future__ import print_function
-
+import re
+import argparse
 import difflib
 import sys
 import os
@@ -18,7 +18,7 @@ from humanfriendly import format_timespan
 
 
 __author__ = 'Erik Moqvist'
-__version__ = '5.7.0'
+__version__ = '5.9.0'
 
 
 _RUN_HEADER_FMT ='''
@@ -68,8 +68,8 @@ LOGGER = logging.getLogger(__name__)
 
 
 def configure_logging(filename=None,
-                      console_log_level=logging.INFO,
-                      file_log_level=logging.DEBUG):
+                      console_log_level=None,
+                      file_log_level=None):
     """Configure the logging module to write output to the console and a
     file. The file name is `filename-<date>.log` if `filename` is not
     None, otherwise the file name is ``systest-<date>.log``.
@@ -82,6 +82,12 @@ def configure_logging(filename=None,
 
     """
 
+    if console_log_level is None:
+        console_log_level = logging.INFO
+
+    if file_log_level is None:
+        file_log_level = logging.DEBUG
+
     # Configure the logging module.
     root_logger = logging.getLogger()
     root_logger.setLevel(logging.DEBUG)
@@ -562,29 +568,24 @@ class Sequencer(object):
 
     def __init__(self,
                  name,
-                 testcase_filter=None,
-                 testcase_skip_filter=None,
+                 testcase_pattern=None,
                  dry_run=False,
                  force_serial_execution=False):
         self.name = name
         self.dry_run = dry_run
         self.tests = None
         self.execution_time = 0.0
-        self.testcase_filter = testcase_filter
-        self.testcase_skip_filter = testcase_skip_filter
+        self.testcase_pattern = testcase_pattern
         self.force_serial_execution = force_serial_execution
         self.continue_on_failure = True
         self.run_failed = False
 
     def is_testcase_enabled(self, test):
-        enabled = True
 
-        if self.testcase_filter is not None:
-            enabled = test.name in self.testcase_filter
-
-        if enabled:
-            if self.testcase_skip_filter is not None:
-                enabled = test.name not in self.testcase_skip_filter
+        if self.testcase_pattern is None:
+            enabled = True
+        else:
+            enabled = bool(re.search(self.testcase_pattern, test.name))
 
         return enabled
 
@@ -1003,6 +1004,16 @@ class Sequencer(object):
         self._report_json(basename)
         self._report_dot(basename)
 
+    def report_and_exit(self):
+        self.report()
+
+        if self.run_failed:
+            exit_code = 1
+        else:
+            exit_code = 0
+
+        sys.exit(exit_code)
+
 
 def _make_filename(text):
     result = ""
@@ -1200,3 +1211,44 @@ def _log_traceback():
     for entry in traceback.format_exception(*sys.exc_info()):
         for line in entry.splitlines():
             LOGGER.error(line.rstrip())
+
+
+def setup(name,
+          parser=None,
+          console_log_level=None,
+          file_log_level=None):
+    """Basic setup of a test program. Parses command line arguments,
+    configures logging and creates a sequencer called `name`. Returns
+    the sequencer.
+
+    Give `parser` to use a custom argument parser. This functions
+    appends its arguments to it.
+
+    Use `console_log_level` to set the console log level.
+
+    Use `file_log_level` to set the file log level.
+
+    """
+
+    if parser is None:
+        parser = argparse.ArgumentParser()
+
+    parser.add_argument('-c', '--no-continue-on-failure',
+                        action='store_true',
+                        help='Do not continue on test failure.')
+    parser.add_argument(
+        'test_pattern',
+        metavar='test-pattern',
+        nargs='?',
+        help="Only run tests matching given regular expression pattern.")
+
+    args = parser.parse_args()
+
+    if not os.path.exists('logs'):
+        os.mkdir('logs')
+
+    configure_logging('logs/{}'.format(name.replace(' ', '-')),
+                      console_log_level=console_log_level,
+                      file_log_level=file_log_level)
+
+    return Sequencer(name, testcase_pattern=args.test_pattern)
