@@ -1,4 +1,5 @@
 import unittest
+from unittest.mock import patch
 import json
 
 import systest
@@ -260,17 +261,14 @@ class SysTestTest(unittest.TestCase):
 
         self.assert_result(result, Result(17, 0, 0))
 
-    def test_testcase_filter(self):
-        """Use the test execution filter to run a specific testcase in a
+    def test_testcase_pattern(self):
+        """Use the test execution pattern to run a specific testcase in a
         sequence.
 
         """
 
-        # A testcase in `testcase_skip_filter` will be skipped even if it is
-        # in `testcase_filter`.
-        sequencer = Sequencer("filter",
-                              testcase_filter=["fail_1", "test_b", "test_d"],
-                              testcase_skip_filter=["fail_1"])
+        sequencer = Sequencer("pattern",
+                              testcase_pattern="^test_b$")
 
         result = sequencer.run(
             FailTest("1"),
@@ -287,8 +285,8 @@ class SysTestTest(unittest.TestCase):
 
         sequencer.report()
 
-        self.assert_result(result, Result(2, 0, 4))
-        self.assertEqual(NamedTest.count, 2)
+        self.assert_result(result, Result(1, 0, 5))
+        self.assertEqual(NamedTest.count, 1)
         self.assertEqual(NotExecutedTest.count, 0)
         self.assertEqual(FailTest.count, 0)
 
@@ -643,6 +641,35 @@ class SysTestTest(unittest.TestCase):
                 }
             ])
 
+    def test_setup_report_and_exit(self):
+        argv = [
+            'suite',
+            '_a'
+        ]
+
+        with patch('sys.argv', argv):
+            sequencer = systest.setup("My Sequence")
+            result = sequencer.run(NamedTest("a"), NamedTest("b"))
+
+            with self.assertRaises(SystemExit) as cm:
+                sequencer.report_and_exit()
+
+            self.assertEqual(cm.exception.code, 0)
+
+    def test_setup_report_and_exit_error(self):
+        argv = [
+            'suite'
+        ]
+
+        with patch('sys.argv', argv):
+            sequencer = systest.setup("My Sequence")
+            result = sequencer.run(FailTest("a"))
+
+            with self.assertRaises(SystemExit) as cm:
+                sequencer.report_and_exit()
+
+            self.assertEqual(cm.exception.code, 1)
+
 
 systest.configure_logging()
 
